# AWIVE
AWIVE, the acrynomes of Adaptive Water Image Velocimetry Estimator, is a
software package for the estimation of the velocity field from a sequence of
images. It is composed by the methods STIV and OTV, which aim at estimate
velocimetry with a low computational cost.

## Installing

Install and update using pip:

```bash
pip install awive
```

